@@ -1,28 +1,28 @@
 #! /usr/bin/perl
-# $Id: store_att.pl,v 1.2 2001/08/24 09:30:31 parkerpine Exp $
+# $Id: store_att.pl,v 1.3 2001/09/07 11:06:15 parkerpine Exp $
 
 use strict;
-#use lib "../../";
+use lib "../../";
 use Mail::MboxParser;
 
 my @Mboxes;
 my $Dir = shift;
 if (-d $Dir) {
 	opendir DIR, $Dir or die "Error: Could not open $Dir: $!";
-	my @Mboxes = readdir DIR ;
+	@Mboxes = readdir DIR ;
 }
 else {
 	push @Mboxes, $Dir;
 }
 
-my $Mb = new Mail::MboxParser;
+my $Mb = Mail::MboxParser->new($Mboxes[0]);
 
 for my $m (@Mboxes) {
 	my $mbox;
 	if (-e $m) 	{ $mbox = $m }
 	else 		{ $mbox = "$Dir/$m" }
 	$Mb->open($mbox);
-	$_->store_all_attachements('/tmp') for ($Mb->get_messages);
+	$_->store_all_attachements(path => '/tmp') for ($Mb->get_messages);
 }
 		
 	
